[epiphany/mcatanzaro/webapp-profile: 13/19] Finish renaming dot dir -> profile dir
- From: Michael Catanzaro <mcatanzaro src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [epiphany/mcatanzaro/webapp-profile: 13/19] Finish renaming dot dir -> profile dir
- Date: Wed, 20 Mar 2019 14:39:36 +0000 (UTC)
commit a2c755b7445429a5a7080908c0e96845cf042cd4
Author: Michael Catanzaro <mcatanzaro igalia com>
Date: Sun Mar 17 10:21:16 2019 -0500
Finish renaming dot dir -> profile dir
embed/web-extension/ephy-web-extension-main.c | 6 +++---
tests/ephy-file-helpers-test.c | 14 +++++++-------
2 files changed, 10 insertions(+), 10 deletions(-)
---
diff --git a/embed/web-extension/ephy-web-extension-main.c b/embed/web-extension/ephy-web-extension-main.c
index af4234d1f..8e37fb5cd 100644
--- a/embed/web-extension/ephy-web-extension-main.c
+++ b/embed/web-extension/ephy-web-extension-main.c
@@ -36,20 +36,20 @@ webkit_web_extension_initialize_with_user_data (WebKitWebExtension *webkit_exten
{
const char *guid;
const char *server_address;
- const char *dot_dir;
+ const char *profile_dir;
const char *adblock_data_dir;
gboolean private_profile;
gboolean browser_mode;
g_autoptr(GError) error = NULL;
- g_variant_get (user_data, "(&sm&s&s&sbb)", &guid, &server_address, &dot_dir, &adblock_data_dir,
&private_profile, &browser_mode);
+ g_variant_get (user_data, "(&sm&s&s&sbb)", &guid, &server_address, &profile_dir, &adblock_data_dir,
&private_profile, &browser_mode);
if (!server_address) {
g_warning ("UI process did not start D-Bus server, giving up.");
return;
}
- if (!ephy_file_helpers_init (dot_dir, 0, &error))
+ if (!ephy_file_helpers_init (profile_dir, 0, &error))
g_warning ("Failed to initialize file helpers: %s", error->message);
ephy_debug_init ();
diff --git a/tests/ephy-file-helpers-test.c b/tests/ephy-file-helpers-test.c
index f6affd467..50d011e9c 100644
--- a/tests/ephy-file-helpers-test.c
+++ b/tests/ephy-file-helpers-test.c
@@ -47,7 +47,7 @@ test_ephy_file_helpers_init (void)
FileInitTest test;
char *tmp_dir = NULL;
- char *dot_dir = NULL;
+ char *profile_dir = NULL;
gboolean private_profile = FALSE;
gboolean keep_dir = FALSE;
@@ -69,20 +69,20 @@ test_ephy_file_helpers_init (void)
g_assert_true (ephy_file_helpers_init (NULL, test.flags, NULL));
tmp_dir = g_strdup (ephy_file_tmp_dir ());
- dot_dir = g_strdup (ephy_profile_dir ());
+ profile_dir = g_strdup (ephy_profile_dir ());
g_assert_nonnull (tmp_dir);
- g_assert_nonnull (dot_dir);
+ g_assert_nonnull (profile_dir);
/* Should always exist after ephy_file_tmp_dir(). */
g_assert_true (g_file_test (tmp_dir, G_FILE_TEST_EXISTS));
- g_assert_true (g_file_test (dot_dir, G_FILE_TEST_EXISTS) == ensure_exists);
+ g_assert_true (g_file_test (profile_dir, G_FILE_TEST_EXISTS) == ensure_exists);
ephy_file_helpers_shutdown ();
/* Private profiles have their dot_dir inside tmp_dir. */
g_assert_true (g_file_test (tmp_dir, G_FILE_TEST_EXISTS) == keep_dir);
- g_assert_true (g_file_test (dot_dir, G_FILE_TEST_EXISTS) == (keep_dir && ensure_exists));
+ g_assert_true (g_file_test (profile_dir, G_FILE_TEST_EXISTS) == (keep_dir && ensure_exists));
/* Cleanup dir left behind. */
if (keep_dir) {
@@ -95,7 +95,7 @@ test_ephy_file_helpers_init (void)
}
g_free (tmp_dir);
- g_free (dot_dir);
+ g_free (profile_dir);
}
}
[
@@ -69,20 +69,20 @@ test_ephy_file_helpers_init (void)
ephy_file_helpers_shutdown ();
- /* Private profiles have their dot_dir inside tmp_dir. */
+ /* Private profiles have their profile_dir inside tmp_dir. */
g_assert_true (g_file_test (tmp_dir, G_FILE_TEST_EXISTS) == keep_dir);
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]